@@ -1,10 +1,7 @@
-import datetime
 import random
 
 import requests
 
-from typing import Any, List, Dict, Tuple
-
 from .data import string_to_raw, time_to_raw, float_to_raw
 from .stream import Stream
 
@@ -83,7 +80,7 @@ class Client:
 
         return obj
 
-    def create_object(self, abstracts: List[str], name='', space=None):
+    def create_object(self, abstracts, name='', space=None, dependent=False):
         if not space:
             if not self.__space:
                 raise RuntimeError('no universe or space selected')
@@ -92,10 +89,11 @@ class Client:
         return self.__post(f'{self.__system_url}objects', {
             'abstracts': self.resolve(abstracts),
             'space': space,
-            'name': name
+            'name': name,
+            'dependent': dependent,
         })['object']
 
-    def create_relation(self, origin_id: str, target_id: str, abstracts: List[str], name='', space: str | None = None, time: datetime.datetime | None = None):
+    def create_relation(self, origin_id, target_id, abstracts, name='', space=None, time=None):
         if not space:
             if not self.__space:
                 raise RuntimeError('no universe or space selected')
@@ -157,7 +155,7 @@ class Client:
             data = float_to_raw(value)
         elif data == 'time':
             data = time_to_raw(value)
-        target = self.create_object([target_id])
+        target = self.create_object([target_id], dependent=True)
         self.set_data(target['id'], data)
         r = self.create_relation(id, target['id'], [field_id], time=time)
         return r
@@ -166,13 +164,13 @@ class Client:
         vals = self.get_values(id, field)
         return vals[0] if len(vals) == 1 else None
 
-    def get_values(self, id: str, field: str) -> List[any]:
+    def get_values(self, id: str, field: str):
         field_id = self.resolve(field)
         query, abbr = self.__get_values_query(field_id, 'val')
         vals = self.query(query, {'obj': {'id': id}, abbr: {'id': field_id}})
         return [v['val'] for v in vals]
 
-    def get_dict_values(self, id: str, defs: dict, names: List[str]) -> List[dict] | None:
+    def get_dict_values(self, id: str, defs: dict, names):
         query = ''
         d = {}
         v = {}
@@ -196,13 +194,13 @@ class Client:
     def stream(self) -> Stream:
         return Stream(self, self.__stream_url)
 
-    def query(self, query, valuation: Dict[str, dict]) -> List[any] | None:
+    def query(self, query, valuation):
         return self.__post(f'{self.__system_url}text_query', {
             'query': query,
             'valuation': valuation,
         })['valuations']
 
-    def __get_values_query(self, field_id: str, name: str) -> Tuple[str, str]:
+    def __get_values_query(self, field_id, name):
         targets = self.get_targets(field_id)
         target_id = targets['ffffffffffffffffffffffffffffffff']
         data = self.__get_type(target_id)
@@ -245,7 +243,7 @@ class Client:
             cache[ck] = rel
         return rel
 
-    def __get(self, url, is_json=True, **kwargs) -> Any:
+    def __get(self, url, is_json=True, **kwargs):
         resp = requests.get(url, headers=self.__get_headers(), **kwargs)
         if resp.status_code == 200:
             return resp.json() if is_json else resp.content
@@ -254,7 +252,7 @@ class Client:
                 return self.__get(url, is_json=is_json, **kwargs)
         return None
 
-    def __post(self, url, data: Any, is_json=True, **kwargs) -> Any:
+    def __post(self, url, data, is_json=True, **kwargs):
         if is_json:
             resp = requests.post(url, json=data, headers=self.__get_headers(), **kwargs)
         else:
@@ -266,7 +264,7 @@ class Client:
                 return self.__post(url, data=data, is_json=is_json, **kwargs)
         return None
 
-    def __put(self, url, data: Any, is_json=True, **kwargs) -> Any:
+    def __put(self, url, data, is_json=True, **kwargs):
         if is_json:
             resp = requests.post(url, json=data, headers=self.__get_headers(), **kwargs)
         else:
@@ -278,7 +276,7 @@ class Client:
                 return self.__put(url, data=data, is_json=is_json, **kwargs)
         return None
 
-    def __delete(self, url, is_json=True, **kwargs) -> Any:
+    def __delete(self, url, is_json=True, **kwargs):
         resp = requests.delete(url, headers=self.__get_headers(), **kwargs)
         if resp.status_code == 200:
             return resp.json() if is_json else resp.content
