@@ -3,15 +3,15 @@ import math
 import struct
 
 
-def string_to_raw(s: str) -> bytes:
+def string_to_raw(s):
     return bytes(s, 'utf8')
 
 
-def float_to_raw(f: float) -> bytes:
+def float_to_raw(f):
     return struct.pack('<d', f)
 
 
-def time_to_raw(t: datetime.datetime) -> bytes:
+def time_to_raw(t):
     bts = bytearray(15)
     bts[0] = 1
 
